==> wiredtiger-2.7.0.tar.bz2: wiredtiger-2.7.0/test/suite/test_baseconfig.py <==
#!/usr/bin/env python
#
# Public Domain 2014-2015 MongoDB, Inc.
# Public Domain 2008-2014 WiredTiger, Inc.
#
# This is free and unencumbered software released into the public domain.
#
# Anyone is free to copy, modify, publish, use, compile, sell, or
# distribute this software, either in source code form or as a compiled
# binary, for any purpose, commercial or non-commercial, and by any
# means.
#
# In jurisdictions that recognize copyright laws, the author or authors
# of this software dedicate any and all copyright interest in the
# software to the public domain. We make this dedication for the benefit
# of the public at large and to the detriment of our heirs and
# successors. We intend this dedication to be an overt act of
# relinquishment in perpetuity of all present and future rights to this
# software under copyright law.
#
# THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND,
# EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF
# MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT.
# IN NO EVENT SHALL THE AUTHORS BE LIABLE FOR ANY CLAIM, DAMAGES OR
# OTHER LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE,
# ARISING FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR
# OTHER DEALINGS IN THE SOFTWARE.

import os
import wiredtiger, wttest

# test_baseconfig
#       test base configuration file being ignored.
class test_baseconfig(wttest.WiredTigerTestCase):
    def test_baseconfig(self):
        # Open up another database and modify the baseconfig
        os.mkdir("A")
        conn = wiredtiger.wiredtiger_open("A", 'create')
        self.assertTrue(os.path.exists("A/WiredTiger.basecfg"))
        with open("A/WiredTiger.basecfg", "a") as basecfg_file:
            basecfg_file.write("foo!")
        conn.close()

        # Open a database, we should assert here as the basecfg is invalid
        self.assertRaisesWithMessage(
            wiredtiger.WiredTigerError,
            lambda: wiredtiger.wiredtiger_open("A", ''),
            '/unknown configuration key/')

        conn = wiredtiger.wiredtiger_open("A", "create,config_base=false")
        conn.close()

if __name__ == '__main__':
    wttest.run()

==> wiredtiger_3.2.1.orig.tar.bz2: wiredtiger-3.2.1/test/suite/test_baseconfig.py <==
#!/usr/bin/env python
#
# Public Domain 2014-2019 MongoDB, Inc.
# Public Domain 2008-2014 WiredTiger, Inc.
#
# This is free and unencumbered software released into the public domain.
#
# Anyone is free to copy, modify, publish, use, compile, sell, or
# distribute this software, either in source code form or as a compiled
# binary, for any purpose, commercial or non-commercial, and by any
# means.
#
# In jurisdictions that recognize copyright laws, the author or authors
# of this software dedicate any and all copyright interest in the
# software to the public domain. We make this dedication for the benefit
# of the public at large and to the detriment of our heirs and
# successors. We intend this dedication to be an overt act of
# relinquishment in perpetuity of all present and future rights to this
# software under copyright law.
#
# THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND,
# EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF
# MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT.
# IN NO EVENT SHALL THE AUTHORS BE LIABLE FOR ANY CLAIM, DAMAGES OR
# OTHER LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE,
# ARISING FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR
# OTHER DEALINGS IN THE SOFTWARE.

import os
import wiredtiger, wttest

# test_baseconfig
#       test base configuration file being ignored.
class test_baseconfig(wttest.WiredTigerTestCase):
    def test_baseconfig(self):
        # Open up another database and modify the baseconfig
        os.mkdir("A")
        conn = self.wiredtiger_open("A", 'create')
        # Mark the new directory as corrupted
        self.databaseCorrupted("A")
        self.assertTrue(os.path.exists("A/WiredTiger.basecfg"))
        with open("A/WiredTiger.basecfg", "a") as basecfg_file:
            basecfg_file.write("foo!")
        conn.close()

        # Open a database, we should assert here as the basecfg is invalid
        self.assertRaisesWithMessage(
            wiredtiger.WiredTigerError,
            lambda: self.wiredtiger_open("A", ''),
            '/unknown configuration key/')

        conn = self.wiredtiger_open("A", "create,config_base=false")
        conn.close()

if __name__ == '__main__':
    wttest.run()
